from __future__ import unicode_literals

from autocomplete_light import shortcuts as al

from django.contrib.auth import get_user_model
from django.utils.translation import ugettext_lazy as _

from .models import Organization, OrganizationGroup, Contact
from jmb.core.utils.autocomplete import DynamicAutocompleteModelBase

al.register(
    Organization, search_fields=['code', 'name', 'vat_number'],
)

User = get_user_model()

#: user autocompletes
class UserAutocomplete(al.AutocompleteModelBase):
    search_fields = ['username', 'last_name', 'first_name', 'email']
    choices = User.objects.all()
    model = User
    autocomplete_js_attributes = {
        'minimum_characters': 0
    }


al.register(UserAutocomplete, name="User")

class OrganizationGroupAutocomplete(al.AutocompleteModelBase):
    search_fields = ['name', ]
    choices = OrganizationGroup.objects.all()
    model = OrganizationGroup
    autocomplete_js_attributes = {
        'minimum_characters': 0
    }

al.register(OrganizationGroupAutocomplete, name='OrganizationGroup')

#: organization autocompletes
class OrganizationAutocomplete(al.AutocompleteModelBase):
    search_fields = ['code', 'name']
    choices = Organization.objects.filter()
    autocomplete_js_attributes = {'placeholder': _('Organization'), }
    model = Organization
al.register(OrganizationAutocomplete, name="Organization")

class OwnerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.owners.filter()
    autocomplete_js_attributes = {
        'minimum_characters': 0,
    }
al.register(OwnerOrganizationAutocomplete, name="OwnerOrganization")

class CustomerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.customers.all()
    autocomplete_js_attributes = {
        'minimum_characters': 0,
        'placeholder': _('click to get the complete list'),
    }
al.register(CustomerOrganizationAutocomplete, name="CustomerOrganization")

class CustomerOwnerOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.customers_owners.filter(status=1)

al.register(CustomerOwnerOrganizationAutocomplete, name="CustomerOwnerOrganization")

class SupplierOrganizationAutocomplete(OrganizationAutocomplete):
    choices = Organization.suppliers.all()
al.register(SupplierOrganizationAutocomplete, name="SupplierOrganization")

#: contact autocomplete
class ContactAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['last_name', 'first_name']
    choices = Contact.objects.all()
    autocomplete_js_attributes = {'placeholder': _('Contact'), }
    model = Contact
al.register(ContactAutocomplete, name="Contact")


class OwnerContactAutocomplete(ContactAutocomplete):
    choices = Contact.owners.filter()
    attrs = {}
al.register(OwnerContactAutocomplete, name="OwnerContact")


class CustomerContactAutocomplete(ContactAutocomplete):
    model = Contact
    filters = {
        'organization_id': '#id_organization',
    }
    autocomplete_js_attributes = {
        'minimum_characters': 0,
    }

al.register(CustomerContactAutocomplete, name="CustomerContact")


class SupplierContactAutocomplete(ContactAutocomplete):
    choices = Contact.suppliers.filter()
al.register(SupplierContactAutocomplete, name="SupplierContact")


class WorkerContactAutocomplete(ContactAutocomplete):
    choices = Contact.workers.filter()
    attrs = {}
al.register(WorkerContactAutocomplete, name="WorkerContact")
