# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import ckeditor.fields
from django.conf import settings
import jmb.core.db
import jmb.address.utils


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('i18n', '__first__'),
        ('vat', '0001_initial'),
        ('payment', '0001_initial'),
        ('l10n', '__first__'),
        ('currency', '0001_initial'),
        ('address', '0001_initial'),
        ('office', '0001_initial'),
        ('carriage', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('default', models.BooleanField(default=False, verbose_name='Default')),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(db_index=True, max_length=15, null=True, verbose_name='code', blank=True)),
                ('last_name', models.CharField(max_length=100, null=True, verbose_name='Last Name', blank=True)),
                ('first_name', models.CharField(max_length=100, null=True, verbose_name='First Name', blank=True)),
                ('phone', models.CharField(max_length=20, null=True, verbose_name='Phone', blank=True)),
                ('mobile', models.CharField(max_length=20, null=True, verbose_name='Mobile', blank=True)),
                ('fax', models.CharField(max_length=20, null=True, verbose_name='Fax', blank=True)),
                ('email', models.EmailField(max_length=100, null=True, verbose_name='Email', blank=True)),
                ('note', models.TextField(max_length=255, null=True, verbose_name='Note', blank=True)),
                ('in_addressbook', models.NullBooleanField(help_text='If this number is in the phone address book.', verbose_name='in rubrica')),
                ('send_procedure_by_email', models.BooleanField(default=False, verbose_name='Send Procedure by email')),
                ('send_ddt_by_email', models.BooleanField(default=False, verbose_name='Send DDT by email')),
                ('send_invoice_by_email', models.BooleanField(default=False, verbose_name='Send Invoice by email')),
                ('send_quotation_by_email', models.BooleanField(default=False, verbose_name='Send Quotation by email')),
                ('photo', models.ImageField(upload_to='contact_photo', null=True, verbose_name='Photo', blank=True)),
            ],
            options={
                'ordering': ['ordering', 'last_name', 'first_name'],
                'verbose_name': 'contact',
                'verbose_name_plural': 'contacts',
                'permissions': (('view_contact', 'Can view contacts'),),
            },
            bases=(models.Model, ),
        ),
        migrations.CreateModel(
            name='ContactRole',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('name', models.CharField(unique=True, max_length=100, verbose_name='name', db_index=True)),
                ('creator', models.ForeignKey(related_name='organization_contactrole_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_contactrole_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('name',),
                'verbose_name': 'Contact role',
                'verbose_name_plural': 'Contact roles',
            },
        ),
        migrations.CreateModel(
            name='ContactTitle',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('name', models.CharField(unique=True, max_length=100, verbose_name='name', db_index=True)),
                ('abbreviation', models.CharField(unique=True, max_length=10, verbose_name='abbreviation')),
                ('creator', models.ForeignKey(related_name='organization_contacttitle_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_contacttitle_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('name',),
                'verbose_name': 'Contact title',
                'verbose_name_plural': 'Contact titles',
            },
        ),
        migrations.CreateModel(
            name='Field',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(unique=True, max_length=15, verbose_name='code', db_index=True)),
                ('name', models.CharField(unique=True, max_length=100, verbose_name='name', db_index=True)),
                ('description', models.TextField(null=True, verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='organization_field_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_field_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'field',
                'verbose_name_plural': 'fields',
            },
        ),
        migrations.CreateModel(
            name='Organization',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(unique=True, max_length=15, verbose_name='code', db_index=True)),
                ('name', models.CharField(max_length=100, verbose_name='name', db_index=True)),
                ('brand', models.CharField(db_index=True, max_length=255, null=True, verbose_name='brand', blank=True)),
                ('ssn', models.CharField(max_length=16, null=True, verbose_name='ssn', db_index=True)),
                ('vat_number', models.CharField(max_length=14, null=True, verbose_name='vat number', db_index=True)),
                ('url', models.URLField(max_length=100, null=True, verbose_name='url', blank=True)),
                ('email', models.EmailField(max_length=100, null=True, verbose_name='email', blank=True)),
                ('phone', models.CharField(max_length=20, verbose_name='phone')),
                ('phone2', models.CharField(max_length=20, null=True, verbose_name='phone2', blank=True)),
                ('fax', models.CharField(max_length=20, null=True, verbose_name='fax', blank=True)),
                ('note', ckeditor.fields.RichTextField(null=True, verbose_name='note', blank=True)),
                ('creator', models.ForeignKey(related_name='organization_organization_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('currency', models.ForeignKey(related_name='organizations', verbose_name='Currency', blank=True, to='currency.Currency', null=True)),
                ('delivery', models.ForeignKey(related_name='organizations', verbose_name='Delivery', blank=True, to='carriage.Delivery', null=True)),
                ('field', models.ForeignKey(related_name='organizations', verbose_name='Field', blank=True, to='organization.Field', null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_organization_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('office', models.ForeignKey(related_name='organizations', verbose_name='office', blank=True, to='office.Office', null=True)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'organization',
                'verbose_name_plural': 'organizations',
                'permissions': (('view_organization', 'Can view organizations'), ('save_addressbook', 'Can save in phone addreebook')),
            },
            bases=(models.Model, ),
        ),
        migrations.CreateModel(
            name='OrganizationAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('address_type', models.IntegerField(default=7, choices=[(1, 'Corso'), (2, 'Largo'), (3, 'Localit\xe0'), (4, 'Piazza'), (5, 'Strada/Stretto'), (6, 'Traversa'), (7, 'Via'), (8, 'Viale'), (9, 'Vicolo/Vico'), (10, 'Circonvallazione'), (11, 'Frazione'), (12, 'Rione'), (13, 'Salita'), (14, 'Contrada'), (15, 'Statale'), (16, 'Autostrada'), (17, 'Cascina'), (18, 'Parco'), (19, 'Spalto'), (20, 'Tangenziale'), (21, 'Zona industriale'), (22, 'Borgo'), (23, 'Galleria'), (24, 'Piazzale'), (25, 'Corte'), (26, 'Centro'), (27, 'Foro'), (28, 'Lungo/Lungomare'), (29, 'Calle'), (30, 'Riviera'), (31, 'Villaggio'), (32, 'Passaggio'), (33, 'Borgata'), (34, 'Lungolago')], blank=True, null=True, verbose_name='address type', db_index=True)),
                ('name', models.CharField(max_length=100, verbose_name='name', db_index=True)),
                ('number', models.CharField(max_length=20, null=True, verbose_name='number', db_column='anumber', blank=True)),
                ('crossed', models.CharField(max_length=5, null=True, verbose_name='crossed', blank=True)),
                ('scale', models.CharField(max_length=5, null=True, verbose_name='scale', blank=True)),
                ('floor', models.CharField(max_length=3, null=True, verbose_name='floor', blank=True)),
                ('zip_code', models.CharField(db_index=True, max_length=20, null=True, verbose_name='zip code', blank=True)),
                ('locality', models.CharField(db_index=True, max_length=100, null=True, verbose_name='locality', blank=True)),
                ('province', models.CharField(db_index=True, max_length=3, null=True, verbose_name='province', blank=True)),
                ('post_office', models.CharField(max_length=10, null=True, verbose_name='post office', blank=True)),
                ('org_name', models.CharField(db_index=True, max_length=100, null=True, verbose_name='Organization Name', blank=True)),
                ('note', models.TextField(null=True, verbose_name='note', blank=True)),
                ('address_scopes', models.ManyToManyField(to='address.AddressScope', verbose_name='address scopes', db_index=True)),
                ('country', models.ForeignKey(default=jmb.address.utils.get_default_country, verbose_name='country', to='l10n.Country')),
                ('creator', models.ForeignKey(related_name='organization_organizationaddress_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_organizationaddress_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('organization', models.ForeignKey(related_name='addresses', verbose_name='organization', to='organization.Organization')),
            ],
            options={
                'verbose_name': 'organization address',
                'verbose_name_plural': 'organization addresses',
            },
        ),
        migrations.CreateModel(
            name='OrganizationForm',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(unique=True, max_length=15, verbose_name='code', db_index=True)),
                ('name', models.CharField(unique=True, max_length=100, verbose_name='name', db_index=True)),
                ('description', models.TextField(null=True, verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='organization_organizationform_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_organizationform_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'organization form',
                'verbose_name_plural': 'organization forms',
            },
        ),
        migrations.CreateModel(
            name='OrganizationGroup',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('name', models.CharField(unique=True, max_length=100, verbose_name='name', db_index=True)),
                ('description', models.TextField(null=True, verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='organization_organizationgroup_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_organizationgroup_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'organization group',
                'verbose_name_plural': 'organization groups',
            },
        ),
        migrations.CreateModel(
            name='OrganizationType',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(unique=True, max_length=15, verbose_name='code', db_index=True)),
                ('category', models.CharField(db_index=True, max_length=15, verbose_name='category', choices=[('com', 'owner company'), ('cus', 'customer'), ('sup', 'supplier'), ('vec', 'vector')])),
                ('name', models.CharField(unique=True, max_length=100, verbose_name='name', db_index=True)),
                ('description', models.TextField(null=True, verbose_name='description', blank=True)),
                ('note', models.TextField(null=True, verbose_name='background informations', blank=True)),
                ('creator', models.ForeignKey(related_name='organization_organizationtype_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='organization_organizationtype_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'organization type',
                'verbose_name_plural': 'organization types',
            },
        ),
        migrations.AddField(
            model_name='organization',
            name='organization_form',
            field=models.ForeignKey(related_name='organizations', verbose_name='Organization form', to='organization.OrganizationForm'),
        ),
        migrations.AddField(
            model_name='organization',
            name='organization_groups',
            field=models.ManyToManyField(related_name='organizations', db_index=True, verbose_name='group', to='organization.OrganizationGroup', blank=True),
        ),
        migrations.AddField(
            model_name='organization',
            name='organization_type',
            field=models.ForeignKey(related_name='organizations', verbose_name='Organization type', to='organization.OrganizationType'),
        ),
        migrations.AddField(
            model_name='organization',
            name='payment_form',
            field=models.ForeignKey(related_name='organizations', verbose_name='Payment form', blank=True, to='payment.PaymentForm', null=True),
        ),
        migrations.AddField(
            model_name='organization',
            name='vat',
            field=models.ForeignKey(related_name='organizations', verbose_name='Vat', blank=True, to='vat.Vat', null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='contact_groups',
            field=models.ManyToManyField(related_name='contacts', db_index=True, verbose_name='group', to='organization.OrganizationGroup', blank=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='creator',
            field=models.ForeignKey(related_name='organization_contact_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='language',
            field=models.ForeignKey(blank=True, to='i18n.Language', help_text='language', null=True, verbose_name='language'),
        ),
        migrations.AddField(
            model_name='contact',
            name='last_modifier',
            field=models.ForeignKey(related_name='organization_contact_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='organization',
            field=models.ForeignKey(related_name='contacts', verbose_name='Organization', blank=True, to='organization.Organization', null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='role',
            field=models.ForeignKey(related_name='contacts', verbose_name='Role', blank=True, to='organization.ContactRole', null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='title',
            field=models.ForeignKey(related_name='contacts', verbose_name='Title', blank=True, to='organization.ContactTitle', null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='user',
            field=models.OneToOneField(related_name='contact', null=True, blank=True, to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
        migrations.AlterUniqueTogether(
            name='organization',
            unique_together=set([('vat_number', 'ssn', 'organization_type')]),
        ),
    ]
